# React Hook Result
There are two common ways to implement a hook that returns a result:
1. Returning an array and accessing with `[a, b, ...] = useHook()`
2. Returning an object and accessing with `{a, b, ...} = useHook()`

Under these circumstances, the two are mutually exclusive. This library provides a class that allows accessing hook values in both ways with one object. Simply return an instance of `HookResult` in your hook.

The class is exported as default, so you can import in one of the following ways:
```
// ES6
import HookResult from '@ptolemy2002/react-hook-result';
// CommonJS
const HookResult = require('@ptolemy2002/react-hook-result');
```

## Classes
The following classes are available in the library:

### HookResult
#### Description
A class that allows accessing hook values in both array and object forms. This is useful for hooks that return multiple values, as it allows the user to access the values in the way that is most convenient for them. Accessing a property of the object directly will first look for an existing property with that name, and if it does not exist, it will get the value from the `_data` object.

#### Parameters
- `data` (Object): The data to be returned by the hook. This should be an object with the keys being the names of the values and the values being the values themselves.
- `order` (Array): The order in which each key should be accessed to be iterated over. Any key not present in this array will be placed at the end in the order that they appear when iterating over the object, which may not be consistent across browsers.

#### Instance Properties
- `_data` (Object): The object that holds this instance's data. It is of type `Map` so that we can save the order of the keys consistently. You should never need to directly access this property, but you can.

## Meta
This is a React Library Created by Ptolemy2002's [cra-template-react-library](https://www.npmjs.com/package/@ptolemy2002/cra-template-react-library) template in combination with [create-react-app](https://www.npmjs.com/package/create-react-app). It contains methods of building and publishing your library to npm.
For now, the library makes use of React 18 and does not use TypeScript.

## Peer Dependencies
These should be installed in order to use the library, as npm does not automatically add peer dependencies to your project.
- @types/react: ^18.3.3
- @types/react-dom: ^18.3.0
- react: ^18.3.1
- react-dom: ^18.3.1

## Commands
The following commands exist in the project:

- `npm run uninstall` - Uninstalls all dependencies for the library
- `npm run reinstall` - Uninstalls and then Reinstalls all dependencies for the library
- `npm run example-uninstall` - Uninstalls all dependencies for the example app
- `npm run example-install` - Installs all dependencies for the example app
- `npm run example-reinstall` - Uninstalls and then Reinstalls all dependencies for the example app
- `npm run example-start` - Starts the example app after building the library
- `npm run build` - Builds the library
- `npm run release` - Publishes the library to npm without changing the version
- `npm run release-patch` - Publishes the library to npm with a patch version bump
- `npm run release-minor` - Publishes the library to npm with a minor version bump
- `npm run release-major` - Publishes the library to npm with a major version bump